CTConfig

Struct CTConfig 

pub struct CTConfig<T = u8, const REQUIRE_COMMA: bool = true, const TRAILING_COMMA: bool = false, const PRE_VALIDATE_UTF8: bool = true, const COMMENTS: bool = false> { /* private fields */ }
Compile-time configuration for JSON parsing behavior.

Implementations

Source

impl<T, const A: bool, const B: bool, const C: bool> CTConfig<T, true, A, B, C>

pub fn optional_comma(self) -> CTConfig<T, false, true, B, C>

Makes commas optional. As a side effect trailing commas are allowed automatically.

Source

impl<T, const A: bool, const B: bool, const C: bool> CTConfig<T, A, false, B, C>

pub fn allow_trailing_comma(self) -> CTConfig<T, A, true, B, C>

Allows trailing commas when parsing.

Source

impl<T, const A: bool, const B: bool, const C: bool> CTConfig<T, A, B, true, C>

pub fn disable_utf8_pre_validation(self) -> CTConfig<T, A, B, false, C>

Disables UTF-8 pre-validation, which would otherwise be performed eagerly when possible.

Performing a single UTF-8 validation over the whole source is usually faster than doing it for each JSON string that is parsed. However, it can be considered overhead when the JSON has little to no strings.

Without this, the default behavior is to pre-validate the entire source for UTF-8 when the source is non-volatile and not guaranteed to be valid UTF-8 already.

Source

impl<T, const A: bool, const B: bool, const C: bool, const D: bool> CTConfig<T, A, B, C, D>

pub fn depth_limit<U>(self, v: U) -> CTConfig<U, A, B, C, D>

Sets depth limit for the input JSON.

Source

impl CTConfig

pub fn new() -> Self

Creates a compile-time configuration with default settings.

By default, commas are required and both trailing commas and comments are not allowed.

Source

impl<T, const A: bool, const B: bool, const C: bool> CTConfig<T, A, B, C>

pub fn allow_comments(self) -> CTConfig<T, A, B, C, true>

Available on crate feature comment only.

Allows comments when parsing.