get_with_parser_unchecked

Function get_with_parser_unchecked 

pub unsafe fn get_with_parser_unchecked<'a, S, C, T, P>(
    path: P,
    parser: &mut Parser<'a, S, C>,
) -> T
where S: Source + 'a, C: Config, T: Deserialize<'a>, P: IntoIterator, P::Item: JsonPointer,
Available on crate feature serde only.
Skips to the given path and deserializes the type using the provided parser.

This function’s behavior is undefined if any of the following conditions are not met:

  • The JSON must be valid.
  • The path must exist.
  • The specified type must be deserializable from the provided JSON data.