Number

Struct Number 

pub struct Number(/* private fields */);
Represents a JSON number.

Implementations

Source

impl Number

pub fn from_u64(val: u64) -> Self

Creates JSON number from u64.

pub fn from_i64(val: i64) -> Self

Creates JSON number from i64.

pub fn from_f64(val: f64) -> Option<Self>

Creates JSON number from f64.

Returns None if the number is infinite or NaN.

pub fn as_u64(&self) -> Option<u64>

Returns the number as u64, or None if it is not a positive integer.

pub fn as_i64(&self) -> Option<i64>

Returns the number as i64, or None if it is not a negative integer.

pub fn as_f64(&self) -> Option<f64>

Returns the number as f64, or None if it is not a float.

pub fn is_u64(&self) -> bool

Returns true if the number is an unsigned integer or a positive integer.

pub fn is_i64(&self) -> bool

Returns true if the number is a signed integer or a negative integer.

pub fn is_f64(&self) -> bool

Returns true if the number is a float.