pub unsafe fn get_with_parser_unchecked<'a, S, C, T, P>(
path: P,
parser: &mut Parser<'a, S, C>,
) -> TAvailable on crate feature
serde only.Expand description
Skips to the given path and deserializes the type using the provided parser.
This function’s behavior is undefined if any of the following conditions are not met:
- The JSON must be valid.
- The path must exist.
- The specified type must be deserializable from the provided JSON data.