pub struct Number(/* private fields */);Expand description
Represents a JSON number.
Implementations
Sourceimpl Number
impl Number
Sourcepub fn from_f64(val: f64) -> Option<Self>
pub fn from_f64(val: f64) -> Option<Self>
Creates JSON number from f64.
Returns None if the number is infinite or NaN.
Sourcepub fn as_u64(&self) -> Option<u64>
pub fn as_u64(&self) -> Option<u64>
Returns the number as u64, or None if it is not a positive integer.
Sourcepub fn as_i64(&self) -> Option<i64>
pub fn as_i64(&self) -> Option<i64>
Returns the number as i64, or None if it is not a negative integer.
Sourcepub fn is_u64(&self) -> bool
pub fn is_u64(&self) -> bool
Returns true if the number is an unsigned integer or a positive integer.